@@ -460,6 +460,13 @@ as_rtf <- function(
 #'   A logical value that indicates whether a table should use Word option
 #'   `Keep rows together`.
 #'
+#' @param autonum Automatic Table Numbering
+#'
+#'   `scalar<logical>` // *default:* `TRUE`
+#'
+#'   A logical value that indicates whether a table should use Words built-in
+#'   auto table numbering option in the caption.
+#'   `Automatic Table Numbering`.
 #' @section Examples:
 #'
 #' Use a subset of the [`gtcars`] dataset to create a **gt** table. Add a header
@@ -493,7 +500,8 @@ as_word <- function(
     caption_location = c("top", "bottom", "embed"),
     caption_align = "left",
     split = FALSE,
-    keep_with_next = TRUE
+    keep_with_next = TRUE,
+    autonum = TRUE
 ) {
 
   # Perform input object validation
@@ -513,17 +521,17 @@ as_word <- function(
   #
   # Composition of Word table OOXML
   #
-
-  if (caption_location == "top") {
-
-    header_xml <-
+  #
+  header_xml <-
       as_word_tbl_header_caption(
         data = value,
         align = caption_align,
         split = split,
-        keep_with_next = keep_with_next
+        keep_with_next = ifelse(caption_location == "bottom", FALSE, keep_with_next),
+        autonum = autonum
       )
 
+  if (caption_location == "top") {
     gt_xml <- c(gt_xml, header_xml)
   }
 
@@ -539,17 +547,6 @@ as_word <- function(
   gt_xml <- c(gt_xml, tbl_xml)
 
   if (caption_location == "bottom") {
-
-    # Set `keep_with_next` to FALSE here to prevent it trying to keep
-    # with non-table content
-    header_xml <-
-      as_word_tbl_header_caption(
-        data = value,
-        align = caption_align,
-        split = split,
-        keep_with_next = FALSE
-      )
-
     gt_xml <- c(gt_xml, header_xml)
   }
 
@@ -567,13 +564,16 @@ as_word <- function(
 #' 'Allow row to break across pages'.
 #' @param keep_with_next  TRUE (default) or FALSE indicating whether a table
 #' should use Word option 'keep rows together' is activated when TRUE.
+#' @param autonum TRUE (default) of FALSE indicating whether a table should usee
+#' Word's automatic table numbering in the caption
 #'
 #' @noRd
 as_word_tbl_header_caption <- function(
     data,
     align = "left",
     split = FALSE,
-    keep_with_next = TRUE
+    keep_with_next = TRUE,
+    autonum = TRUE
 ) {
 
   # Perform input object validation
@@ -586,7 +586,8 @@ as_word_tbl_header_caption <- function(
     create_table_caption_component_xml(
       data = data,
       align = align,
-      keep_with_next = keep_with_next
+      keep_with_next = keep_with_next,
+      autonum = autonum
     )
 
   caption_xml
