@@ -14,7 +14,7 @@
 #
 #  This file is part of the 'rstudio/gt' project.
 #
-#  Copyright (c) 2018-2024 gt authors
+#  Copyright (c) 2018-2025 gt authors
 #
 #  For full copyright and license information, please look at
 #  https://gt.rstudio.com/LICENSE.html
@@ -40,7 +40,11 @@ kable_caption <- function(label, caption, format) {
 
 create_label <- function(..., latex = FALSE) {
   if (isTRUE(knitr::opts_knit$get("bookdown.internal.label"))) {
-    lab1 <- "(\\#"
+    if (latex) {
+      lab1 <- "(\\#"
+    } else {
+      lab1 <- "(#"
+    }
     lab2 <- ")"
   } else if (latex) {
     lab1 <- "\\label{"
