@@ -939,6 +939,12 @@ process_text <- function(text, context = "html") {
 
       return(text)
 
+    } else if (inherits(text, "from_latex")) {
+
+      text <- as.character(text)
+
+      return(text)
+
     } else {
 
       text <- escape_latex(text = text)
@@ -973,6 +979,10 @@ process_text <- function(text, context = "html") {
     if (inherits(text, "from_markdown")) {
 
       text <- markdown_to_xml(text)
+    } else if (is_html(text)) {
+
+      text <- markdown_to_xml(unescape_html(linebreak_br(text)))
+
     } else {
       text <- as.character(text)
     }
@@ -1031,6 +1041,13 @@ unescape_html <- function(text) {
   text
 }
 
+
+#' apply a double newline for implementing universal line break in markdown
+#' @noRd
+linebreak_br <- function(x) {
+  gsub("<br>", "\n\n\n", x, fixed = TRUE)
+}
+
 #' Transform Markdown text to HTML and also perform HTML escaping
 #'
 #' @noRd
@@ -1115,6 +1132,8 @@ markdown_to_latex <- function(text, md_engine) {
             return(NA_character_)
           }
 
+          x <- gsub("<br>","..gt_linebreak_indicator..", x)
+
           if (isTRUE(getOption("gt.html_tag_check", TRUE))) {
 
             if (grepl("<[a-zA-Z\\/][^>]*>", x)) {
@@ -1125,11 +1144,19 @@ markdown_to_latex <- function(text, md_engine) {
             }
           }
 
+
           if (names(md_engine_fn) == "commonmark") {
-            gsub("\\n$", "", md_engine_fn[[1]](text = x))
+           x <- gsub("\\n$", "", md_engine_fn[[1]](text = x))
           } else {
-            gsub("\\n$", "", md_engine_fn[[1]](text = x, format = "latex"))
+           x <- gsub("\\n$", "", md_engine_fn[[1]](text = x, format = "latex"))
           }
+
+          if(grepl("..gt\\_linebreak\\_indicator..", x, fixed = TRUE)){
+            x <- paste0("\\shortstack[l]{" ,gsub("..gt\\_linebreak\\_indicator..", " \\\\", x, fixed = TRUE), "}")
+          }
+
+          x
+
         }
       )
     )
@@ -1138,11 +1165,12 @@ markdown_to_latex <- function(text, md_engine) {
 
 # Transform Markdown text to ooxml
 markdown_to_xml <- function(text) {
+
   res <- vapply(
-    as.character(text),
+    gsub("<br>","\n\n",as.character(text)),
     FUN.VALUE = character(1L),
     USE.NAMES = FALSE,
-    FUN = commonmark::markdown_xml
+    FUN = function(x, ...) commonmark::markdown_xml(linebreak_br(x), ...)
   )
   vapply(
     res,
@@ -2215,13 +2243,6 @@ resolve_border_side <- function(side) {
   )
 }
 
-#' Expand a path using fs::path_expand
-#'
-#' @noRd
-path_expand <- function(file) {
-  fs::path_expand(file)
-}
-
 # TODO: the `get_file_ext()` function overlaps greatly with `gtsave_file_ext()`;
 #       both are not vectorized
 
@@ -2478,3 +2499,39 @@ data_get_image_tag <- function(file, dir = "images") {
 }
 
 #nocov end
+
+#' Function to iterate over the gt_tbls in a gt_group and apply a function
+#' @param data gt_group obj
+#' @param arg_list list of function arguments and function name from match.call in parent function
+#' @param call caller env
+#' @importFrom rlang caller_env
+#' @noRd
+apply_to_grp <- function(data, arg_list, call = caller_env()){
+  func <- as.character(arg_list[[1]])
+  args <- arg_list[-1]
+  # check function is a valid gt exported function
+  if(!(func %in% getNamespaceExports("gt"))){
+    cli::cli_abort("{.val {func}} is not an exported gt function")
+  }
+
+  for (i in seq_len(nrow(data$gt_tbls))) {
+    # pull out gt_tbl, apply function, reinsert into group
+    gt_tbl <- grp_pull(data, i)
+    # replace data arg with current gt_tbl
+    args[[1]] <- gt_tbl
+
+    #make it clear which table if an error occurs
+    gt_tbl <- tryCatch({
+      do.call(func, args, envir = call)
+    },
+    error = function(e) {
+      cli::cli_abort("Failure in Table {i}", parent = e)
+    })
+
+    data <- grp_replace(data, gt_tbl, .which = i)
+  }
+
+  data
+}
+
+
