@@ -237,7 +237,7 @@ coalesce_marks <- function(
     delimiter = ","
 ) {
   fs_ids <- vctrs::vec_slice(fn_tbl$fs_id, fn_tbl$locname == locname)
-  paste(fs_ids, collapse = delimiter)
+  paste(sort(fs_ids), collapse = delimiter)
 }
 
 # Get the attributes for the table tag
@@ -580,8 +580,19 @@ create_columns_component_h <- function(data) {
   # If columns are present in the stub, then replace with a set stubhead
   # label or nothing
   if (length(stub_layout) > 0 && length(stubh$label) > 0) {
-    headings_labels <- prepend_vec(headings_labels, stubh$label)
-    headings_vars <- prepend_vec(headings_vars, "::stub")
+    # Check if we have multiple labels for multi-column stub
+    stub_vars <- dt_boxhead_get_var_stub(data = data)
+    has_multi_column_stub <- length(stub_vars) > 1 && !any(is.na(stub_vars))
+
+    if (has_multi_column_stub && length(stubh$label) > 1) {
+      # Multiple labels for multi-column stub - add each label individually
+      headings_labels <- c(stubh$label, headings_labels)
+      headings_vars <- c(paste0("::stub", seq_along(stubh$label)), headings_vars)
+    } else {
+      # Single label (may span multiple columns) - use current behavior
+      headings_labels <- prepend_vec(headings_labels, stubh$label)
+      headings_vars <- prepend_vec(headings_vars, "::stub")
+    }
   } else if (length(stub_layout) > 0) {
     headings_labels <- prepend_vec(headings_labels, "")
     headings_vars <- prepend_vec(headings_vars, "::stub")
@@ -595,7 +606,7 @@ create_columns_component_h <- function(data) {
 
   if (spanner_row_count < 1) {
 
-    # Create the cell for the stubhead label
+    # Create the cell(s) for the stubhead label(s)
     if (length(stub_layout) > 0) {
 
       stubhead_style <-
@@ -605,26 +616,59 @@ create_columns_component_h <- function(data) {
           NULL
         }
 
-      table_col_headings[[length(table_col_headings) + 1]] <-
-        htmltools::tags$th(
-          class = paste(
-            c(
-              "gt_col_heading", "gt_columns_bottom_border",
-              paste0("gt_", stubhead_label_alignment)
-            ),
-            collapse = " "
-          ),
-          rowspan = 1,
-          colspan = length(stub_layout),
-          style = stubhead_style,
-          scope = ifelse(length(stub_layout) > 1, "colgroup", "col"),
-          id = headings_ids[1],
-          htmltools::HTML(headings_labels[1])
-        )
+      # Check if we have multiple stubhead labels for multi-column stub
+      stub_vars <- dt_boxhead_get_var_stub(data = data)
+      has_multi_column_stub <- length(stub_vars) > 1 && !any(is.na(stub_vars))
+      has_multiple_labels <- has_multi_column_stub && length(stubh$label) > 1
 
-      headings_vars <- headings_vars[-1]
-      headings_ids <- headings_ids[-1]
-      headings_labels <- headings_labels[-1]
+      if (has_multiple_labels) {
+        # Create individual <th> elements for each stubhead label
+        for (i in seq_along(stubh$label)) {
+          table_col_headings[[length(table_col_headings) + 1]] <-
+            htmltools::tags$th(
+              class = paste(
+                c(
+                  "gt_col_heading", "gt_columns_bottom_border",
+                  paste0("gt_", stubhead_label_alignment)
+                ),
+                collapse = " "
+              ),
+              rowspan = 1,
+              colspan = 1,
+              style = stubhead_style,
+              scope = "col",
+              id = headings_ids[i],
+              htmltools::HTML(headings_labels[i])
+            )
+        }
+        # Remove the stubhead labels from the lists
+        headings_vars <- headings_vars[-seq_along(stubh$label)]
+        headings_ids <- headings_ids[-seq_along(stubh$label)]
+        headings_labels <- headings_labels[-seq_along(stubh$label)]
+      } else {
+        # Single label spanning all stub columns (current behavior)
+        table_col_headings[[length(table_col_headings) + 1]] <-
+          htmltools::tags$th(
+            class = paste(
+              c(
+                "gt_col_heading", "gt_columns_bottom_border",
+                paste0("gt_", stubhead_label_alignment)
+              ),
+              collapse = " "
+            ),
+            rowspan = 1,
+            colspan = get_stub_column_count(data),
+            style = stubhead_style,
+            scope = ifelse(get_stub_column_count(data) > 1, "colgroup", "col"),
+            id = headings_ids[1],
+            htmltools::HTML(headings_labels[1])
+          )
+
+        # Remove the single stubhead from the lists
+        headings_vars <- headings_vars[-1]
+        headings_ids <- headings_ids[-1]
+        headings_labels <- headings_labels[-1]
+      }
     }
 
     for (i in seq_along(headings_vars)) {
@@ -685,7 +729,7 @@ create_columns_component_h <- function(data) {
     # all column labels that DO have spanners above them.
     spanned_column_labels <- list()
 
-    # Create the cell for the stubhead label
+    # Create the cell(s) for the stubhead label(s)
     if (length(stub_layout) > 0) {
       stubhead_style <-
         if (nrow(stubhead_style_attrs) > 0) {
@@ -694,26 +738,59 @@ create_columns_component_h <- function(data) {
           NULL
         }
 
-      level_1_spanners[[length(level_1_spanners) + 1]] <-
-        htmltools::tags$th(
-          class = paste(
-            c(
-              "gt_col_heading", "gt_columns_bottom_border",
-              paste0("gt_", stubhead_label_alignment)
-            ),
-            collapse = " "
-          ),
-          rowspan = 2,
-          colspan = length(stub_layout),
-          style = stubhead_style,
-          scope = ifelse(length(stub_layout) > 1, "colgroup", "col"),
-          id = headings_ids[1],
-          htmltools::HTML(headings_labels[1])
-        )
+      # Check if we have multiple stubhead labels for multi-column stub
+      stub_vars <- dt_boxhead_get_var_stub(data = data)
+      has_multi_column_stub <- length(stub_vars) > 1 && !any(is.na(stub_vars))
+      has_multiple_labels <- has_multi_column_stub && length(stubh$label) > 1
 
-      headings_ids <- headings_ids[-1]
-      headings_vars <- headings_vars[-1]
-      headings_labels <- headings_labels[-1]
+      if (has_multiple_labels) {
+        # Create individual <th> elements for each stubhead label
+        for (i in seq_along(stubh$label)) {
+          level_1_spanners[[length(level_1_spanners) + 1]] <-
+            htmltools::tags$th(
+              class = paste(
+                c(
+                  "gt_col_heading", "gt_columns_bottom_border",
+                  paste0("gt_", stubhead_label_alignment)
+                ),
+                collapse = " "
+              ),
+              rowspan = 2,
+              colspan = 1,
+              style = stubhead_style,
+              scope = "col",
+              id = headings_ids[i],
+              htmltools::HTML(headings_labels[i])
+            )
+        }
+        # Remove the stubhead labels from the lists
+        headings_ids <- headings_ids[-seq_along(stubh$label)]
+        headings_vars <- headings_vars[-seq_along(stubh$label)]
+        headings_labels <- headings_labels[-seq_along(stubh$label)]
+      } else {
+        # Single label spanning all stub columns (current behavior)
+        level_1_spanners[[length(level_1_spanners) + 1]] <-
+          htmltools::tags$th(
+            class = paste(
+              c(
+                "gt_col_heading", "gt_columns_bottom_border",
+                paste0("gt_", stubhead_label_alignment)
+              ),
+              collapse = " "
+            ),
+            rowspan = 2,
+            colspan = get_stub_column_count(data),
+            style = stubhead_style,
+            scope = ifelse(get_stub_column_count(data) > 1, "colgroup", "col"),
+            id = headings_ids[1],
+            htmltools::HTML(headings_labels[1])
+          )
+
+        # Remove the single stubhead from the lists
+        headings_ids <- headings_ids[-1]
+        headings_vars <- headings_vars[-1]
+        headings_labels <- headings_labels[-1]
+      }
     }
 
     # NOTE: `rle()` treats NA values as distinct from each other;
@@ -1007,6 +1084,7 @@ create_body_component_h <- function(data) {
   list_of_summaries <- dt_summary_df_get(data = data)
   groups_rows_df <- dt_groups_rows_get(data = data)
   styles_tbl <- dt_styles_get(data = data)
+  footnotes_tbl <- dt_footnotes_get(data = data)
 
   # Get effective number of columns
   n_cols_total <- get_effective_number_of_columns(data = data)
@@ -1014,15 +1092,6 @@ create_body_component_h <- function(data) {
   # Get the number of columns for the body cells only
   n_data_cols <- get_number_of_visible_data_columns(data = data)
 
-  # Create ID components for every column that will be rendered
-  col_names_id <-
-    c(
-      if ((n_cols_total - n_data_cols) > 0) {
-        paste0("stub_", seq_len(n_cols_total - n_data_cols))
-      },
-      dt_boxhead_get_vars_default(data = data)
-    )
-
   # Get vector representation of stub layout
   stub_layout <- get_stub_layout(data = data)
 
@@ -1031,6 +1100,16 @@ create_body_component_h <- function(data) {
   has_stub_column <- "rowname" %in% stub_layout
   has_two_col_stub <- "group_label" %in% stub_layout
 
+  # Create ID components for every column that will be rendered
+  col_names_id <-
+    c(
+      if ((n_cols_total - n_data_cols) > 0) {
+        # For all stub columns, use generic stub IDs for backward compatibility
+        paste0("stub_", seq_len(n_cols_total - n_data_cols))
+      },
+      dt_boxhead_get_vars_default(data = data)
+    )
+
   # Get a matrix of all cells in the body (not including summary cells)
   cell_matrix <- get_body_component_cell_matrix(data = data)
 
@@ -1076,9 +1155,23 @@ create_body_component_h <- function(data) {
 
       row_label_col <- which(stub_layout == "rowname")
 
-      extra_classes_1[[row_label_col]] <- "gt_stub"
-      extra_classes_2[[row_label_col]] <-
-        c("gt_stub", if (table_stub_striped) "gt_striped" else NULL)
+      # For multi-column stubs, apply the thick border to all stub columns
+      # This creates a nice visual hierarchy with "boxes" for each level
+      stub_vars <- dt_boxhead_get_var_stub(data = data)
+
+      if (length(stub_vars) > 1 && !any(is.na(stub_vars))) {
+        # Multi-column stub: apply gt_stub class to all stub columns
+        for (i in seq_len(length(stub_vars))) {
+          extra_classes_1[[i]] <- "gt_stub"
+          extra_classes_2[[i]] <-
+            c("gt_stub", if (table_stub_striped) "gt_striped" else NULL)
+        }
+      } else {
+        # Single column stub: apply gt_stub class to the rowname column (existing behavior)
+        extra_classes_1[[row_label_col]] <- "gt_stub"
+        extra_classes_2[[row_label_col]] <-
+          c("gt_stub", if (table_stub_striped) "gt_striped" else NULL)
+      }
     }
   }
 
@@ -1218,6 +1311,11 @@ create_body_component_h <- function(data) {
 
   non_center_alignments <- alignment_classes != "gt_center"
 
+  # Calculate hierarchical stub rowspan information for multi-column stubs
+  # TODO: Re-enable this after fixing vector length issues
+  # hierarchical_stub_info <- calculate_hierarchical_stub_rowspans(data)
+  hierarchical_stub_info <- calculate_hierarchical_stub_rowspans(data)
+
   body_rows_data <- list()
   body_rows_data$row_df <- vector("list", n_rows)
   body_rows_data$col_id_i <- vector("list", n_rows)
@@ -1250,6 +1348,29 @@ create_body_component_h <- function(data) {
     alignment_classes_i <- alignment_classes
     row_span_vals_i <- row_span_vals
 
+    # Apply hierarchical stub rowspan logic if available
+    if (!is.null(hierarchical_stub_info)) {
+      # Get stub variables and layout
+      stub_vars <- dt_boxhead_get_var_stub(data = data)
+
+      if (!(length(stub_vars) == 1 && is.na(stub_vars))) {
+        hierarchy_vars <- stub_vars[-length(stub_vars)]  # Exclude rightmost stub column
+
+        # Apply rowspan values for hierarchical stub columns
+        for (var_idx in seq_along(hierarchy_vars)) {
+          var_name <- hierarchy_vars[var_idx]
+          if (var_name %in% names(hierarchical_stub_info)) {
+            stub_info <- hierarchical_stub_info[[var_name]]
+
+            # Set rowspan for this column if > 1
+            if (stub_info$rowspans[i] > 1) {
+              row_span_vals_i[[var_idx]] <- stub_info$rowspans[i]
+            }
+          }
+        }
+      }
+    }
+
     g <- group_idx[[i]]
     group_id <- groups_list$group_id[g]
     group_row_start <- groups_list$row_start[g]
@@ -1299,11 +1420,21 @@ create_body_component_h <- function(data) {
         rownum = i
       )
 
+    # Get stub column styles separately
+    stub_column_styles <-
+      dt_styles_pluck(
+        styles_tbl = styles_tbl,
+        locname = "stub_column",
+        rownum = i
+      )
+
     row_styles <-
-      build_row_styles(
+      build_row_styles_with_stub_columns(
         styles_resolved_row = styles_row,
+        stub_column_styles = stub_column_styles,
         include_stub = has_stub_column,
-        n_cols = n_data_cols
+        n_cols = n_data_cols,
+        data = data
       )
 
     # Handle the layout case where there is a 'two-column stub', which
@@ -1372,13 +1503,74 @@ create_body_component_h <- function(data) {
         i = i,
         cell_matrix = cell_matrix,
         groups_rows_df = groups_rows_df,
-        has_two_col_stub = has_two_col_stub
+        has_two_col_stub = has_two_col_stub,
+        hierarchical_stub_info = hierarchical_stub_info
       )
 
-    # Situation where we have two columns in the stub and the row label
+    # Apply hierarchical stub logic to filter out elements that should be hidden
+    cols_to_remove <- c()
+    if (!is.null(hierarchical_stub_info)) {
+      stub_vars <- dt_boxhead_get_var_stub(data = data)
+      if (!(length(stub_vars) == 1 && is.na(stub_vars))) {
+        hierarchy_vars <- stub_vars[-length(stub_vars)]  # Exclude rightmost stub column
+
+        for (var_idx in seq_along(hierarchy_vars)) {
+          var_name <- hierarchy_vars[var_idx]
+          if (var_name %in% names(hierarchical_stub_info)) {
+            stub_info <- hierarchical_stub_info[[var_name]]
+
+            # If this row should not display this column's value (it's part of a merge)
+            if (!stub_info$display_mask[i]) {
+              cols_to_remove <- c(cols_to_remove, var_idx)
+            }
+          }
+        }
+      }
+    }
+
+    # Remove the columns/elements that should be hidden
+    if (length(cols_to_remove) > 0) {
+      # Adjust indices if they are beyond the current vector length
+      cols_to_remove <- cols_to_remove[cols_to_remove <= length(row_df)]
+
+      if (length(cols_to_remove) > 0) {
+        row_df <- row_df[-cols_to_remove]
+        # Also remove from other vectors to maintain synchronization
+        if (length(col_id_i) >= max(cols_to_remove)) {
+          col_id_i <- col_id_i[-cols_to_remove]
+        }
+        if (length(row_id_i) >= max(cols_to_remove)) {
+          row_id_i <- row_id_i[-cols_to_remove]
+        }
+        if (length(row_span_vals_i) >= max(cols_to_remove)) {
+          row_span_vals_i <- row_span_vals_i[-cols_to_remove]
+        }
+        if (length(alignment_classes_i) >= max(cols_to_remove)) {
+          alignment_classes_i <- alignment_classes_i[-cols_to_remove]
+        }
+        if (length(has_rtl_i) >= max(cols_to_remove)) {
+          has_rtl_i <- has_rtl_i[-cols_to_remove]
+        }
+        if (length(extra_classes) >= max(cols_to_remove)) {
+          extra_classes <- extra_classes[-cols_to_remove]
+        }
+        if (length(row_styles) >= max(cols_to_remove)) {
+          row_styles <- row_styles[-cols_to_remove]
+        }
+      }
+    }
+
+    # Situation where we have multiple columns in the stub and the row label
     # isn't the first (the `row_df` vector will have one less element)
     if (length(col_names_id) > length(row_df)) {
-      col_id_i <- col_names_id[-(length(col_names_id) - length(row_df))]
+      if (has_two_col_stub && !group_start) {
+        # For 2-column stub non-first rows, skip the group column (first element)
+        # and take the remaining elements that match row_df length
+        col_id_i <- col_names_id[-1][seq_len(length(row_df))]
+      } else {
+        # Take the first n elements where n = length(row_df)
+        col_id_i <- col_names_id[seq_len(length(row_df))]
+      }
     } else {
       col_id_i <- col_names_id
     }
@@ -1387,10 +1579,20 @@ create_body_component_h <- function(data) {
 
     if (stub_width == 0) {
       row_id_i <- character(length(col_id_i))
+    } else if (has_two_col_stub) {
+      # For group labels as columns (2-column stub), we always use stub_2_X pattern
+      row_id_i <- rep(paste0("stub_2_", i), length(col_id_i))
     } else if (stub_width == 1) {
-      row_id_i <- rep(paste0(col_id_i[1], "_", i), length(col_id_i))
-    } else if (stub_width == 2) {
-      row_id_i <- rep(paste0(col_id_i[2], "_", i), length(col_id_i))
+      # Always use stub_1_X pattern for row IDs when there's a stub
+      row_id_i <- rep(paste0("stub_1_", i), length(col_id_i))
+    } else {
+      # For multi-column stubs (>= 2), use stub_X_Y pattern
+      last_stub_idx <- min(stub_width, length(col_id_i))
+      if (last_stub_idx > 0) {
+        row_id_i <- rep(paste0("stub_", last_stub_idx, "_", i), length(col_id_i))
+      } else {
+        row_id_i <- character(length(col_id_i))
+      }
     }
 
     # In the situation where there is:
@@ -1418,6 +1620,49 @@ create_body_component_h <- function(data) {
       row_styles <- row_styles[-1]
     }
 
+    # Ensure all vectors have the same length before adding to body_rows_data
+    target_length <- length(row_df)
+
+    # Truncate or pad vectors to match row_df length
+    col_id_i <- col_id_i[seq_len(min(length(col_id_i), target_length))]
+    if (length(col_id_i) < target_length) {
+      col_id_i <- c(col_id_i, rep(NA_character_, target_length - length(col_id_i)))
+    }
+
+    row_id_i <- row_id_i[seq_len(min(length(row_id_i), target_length))]
+    if (length(row_id_i) < target_length) {
+      row_id_i <- c(row_id_i, rep(NA_character_, target_length - length(row_id_i)))
+    }
+
+    row_span_vals_i <- row_span_vals_i[seq_len(min(length(row_span_vals_i), target_length))]
+    if (length(row_span_vals_i) < target_length) {
+      row_span_vals_i <- c(row_span_vals_i, rep(NA_integer_, target_length - length(row_span_vals_i)))
+    }
+
+    alignment_classes_i <- alignment_classes_i[seq_len(min(length(alignment_classes_i), target_length))]
+    if (length(alignment_classes_i) < target_length) {
+      alignment_classes_i <- c(alignment_classes_i, rep("gt_left", target_length - length(alignment_classes_i)))
+    }
+
+    has_rtl_i <- has_rtl_i[seq_len(min(length(has_rtl_i), target_length))]
+    if (length(has_rtl_i) < target_length) {
+      has_rtl_i <- c(has_rtl_i, rep(FALSE, target_length - length(has_rtl_i)))
+    }
+
+    if (length(extra_classes) != target_length) {
+      if (length(extra_classes) > target_length) {
+        extra_classes <- extra_classes[seq_len(target_length)]
+      } else {
+        # Pad with empty lists
+        extra_classes <- c(extra_classes, replicate(target_length - length(extra_classes), list(character(0)), simplify = FALSE))
+      }
+    }
+
+    row_styles <- row_styles[seq_len(min(length(row_styles), target_length))]
+    if (length(row_styles) < target_length) {
+      row_styles <- c(row_styles, rep(NA_character_, target_length - length(row_styles)))
+    }
+
     body_rows_data$row_df[[i]] <- row_df
     body_rows_data$col_id_i[[i]] <- col_id_i
     body_rows_data$row_id_i[[i]] <- row_id_i
@@ -1586,7 +1831,8 @@ output_df_row_as_vec <- function(
     i,
     cell_matrix,
     groups_rows_df,
-    has_two_col_stub
+    has_two_col_stub,
+    hierarchical_stub_info = NULL
 ) {
 
   cell_matrix <- cell_matrix[i, ]
@@ -1604,216 +1850,208 @@ output_df_row_as_vec <- function(
   cell_matrix
 }
 
-#' Create the table source note component (HTML)
+#' Create the combined table footer component
 #'
 #' @noRd
-create_source_notes_component_h <- function(data) {
+create_footer_component_h <- function(data) {
 
   source_notes <- dt_source_notes_get(data = data)
+  footnotes_tbl <- dt_footnotes_get(data = data)
 
-  if (is.null(source_notes)) {
+  # If there are no source notes and no footnotes, return empty string
+  if (is.null(source_notes) && nrow(footnotes_tbl) == 0) {
     return("")
   }
 
   styles_tbl <- dt_styles_get(data = data)
-
-  # Get effective number of columns
   n_cols_total <- get_effective_number_of_columns(data = data)
 
-  # Get the style attrs for the source notes
-  if ("source_notes" %in% styles_tbl$locname) {
+  # Collect all footer rows
+  footer_rows <- list()
 
-    source_notes_style <-
-      vctrs::vec_slice(
-        styles_tbl$html_style,
-        !is.na(styles_tbl$locname) & styles_tbl$locname == "source_notes"
-        )
+  # Add footnote rows first (footnotes should appear above source notes)
+  if (nrow(footnotes_tbl) > 0) {
 
-    source_notes_styles <-
-      if (length(source_notes_style) > 0) {
-        paste(source_notes_style, collapse = " ")
-      } else {
-        NULL
-      }
+    # Ensure `fs_id` column exists (it should have been added by
+    # `resolve_footnotes_styles()`)
+    if (!"fs_id" %in% names(footnotes_tbl)) {
+      # Add a temporary fs_id based on row numbers as fallback
+      footnotes_tbl$fs_id <- as.character(seq_len(nrow(footnotes_tbl)))
+    }
 
-  } else {
-    source_notes_styles <- NULL
-  }
+    # Get the distinct set of `fs_id` & `footnotes` values
+    # in the `footnotes_tbl`
+    footnotes_tbl <- dplyr::distinct(footnotes_tbl, fs_id, footnotes)
 
-  # Get the source note multiline option
-  multiline <- dt_options_get_value(data = data, option = "source_notes_multiline")
+    # Get the style attrs for the footnotes
+    footnotes_styles <- NULL
+    if ("footnotes" %in% styles_tbl$locname) {
+      footnotes_style <- styles_tbl[styles_tbl$locname == "footnotes", ]
 
-  # Get the source note separator option
-  separator <- dt_options_get_value(data = data, option = "source_notes_sep")
+      footnotes_styles <-
+        if (nrow(footnotes_style) > 0) {
+          paste(footnotes_style$html_style, collapse = " ")
+        } else {
+          NULL
+        }
+    }
 
-  # Handle the multiline source notes case (each footnote takes up one line)
-  if (multiline) {
-    # Create the source notes component as a series of `<tr><td>` (one per
-    # source note) inside of a `<tfoot>`
-    return(
-      htmltools::tags$tfoot(
-        class = "gt_sourcenotes",
-        lapply(
-          source_notes,
-          function(x) {
-            htmltools::tags$tr(
-              htmltools::tags$td(
-                class = "gt_sourcenote",
-                style = source_notes_styles,
-                colspan = n_cols_total,
-                htmltools::HTML(x)
+    # Get the footnote multiline option
+    footnotes_multiline <-
+      dt_options_get_value(data = data, option = "footnotes_multiline")
+
+    # Get the footnote separator option
+    footnotes_separator <-
+      dt_options_get_value(data = data, option = "footnotes_sep")
+
+    # Obtain vectors of footnote ID values (prerendered glyphs) and
+    # the associated text
+    footnote_ids <- footnotes_tbl[["fs_id"]]
+    footnote_text <- footnotes_tbl[["footnotes"]]
+
+    # Create a vector of HTML footnotes
+    footnotes <-
+      unlist(
+        mapply(
+          SIMPLIFY = FALSE,
+          USE.NAMES = FALSE,
+          footnote_ids,
+          footnote_text,
+          FUN = function(x, footnote_text) {
+            as.character(
+              htmltools::tagList(
+                htmltools::HTML(
+                  paste0(
+                    footnote_mark_to_html(
+                      data = data,
+                      mark = x,
+                      location = "ftr"
+                    ),
+                    " ",
+                    process_text(footnote_text, context = "html")
+                  ),
+                  .noWS = c("after", "before")
+                )
               )
             )
           }
         )
       )
-    )
-  }
 
-  # Perform HTML escaping on the separator text and transform space
-  # characters to non-breaking spaces
-  separator <- gsub(" (?= )", "&nbsp;", separator, perl = TRUE)
-
-  # Create the source notes component as a single `<tr><td>` inside
-  # of a `<tfoot>`
-  htmltools::tags$tfoot(
-    htmltools::tags$tr(
-      class = "gt_sourcenotes",
-      style = source_notes_styles,
-      htmltools::tags$td(
-        class = "gt_sourcenote",
-        colspan = n_cols_total,
-        htmltools::tags$div(
-          style = htmltools::css(`padding-bottom` = "2px"),
-          htmltools::HTML(paste(source_notes, collapse = separator))
-        )
-      )
-    )
-  )
-}
-
-#' Create the table footnote component (HTML)
-#'
-#' @noRd
-create_footnotes_component_h <- function(data) {
-
-  footnotes_tbl <- dt_footnotes_get(data = data)
-
-  # If the `footnotes_resolved` object has no
-  # rows, then return an empty footnotes component
-  if (nrow(footnotes_tbl) == 0) {
-    return("")
-  }
-
-  styles_tbl <- dt_styles_get(data = data)
-
-  # Get the effective number of columns
-  n_cols_total <- get_effective_number_of_columns(data = data)
-
-  # Get the distinct set of `fs_id` & `footnotes` values in the `footnotes_tbl`
-  footnotes_tbl <- dplyr::distinct(footnotes_tbl, fs_id, footnotes)
-
-  # Get the style attrs for the footnotes
-  if ("footnotes" %in% styles_tbl$locname) {
-
-    footnotes_style <- styles_tbl[styles_tbl$locname == "footnotes", ]
-
-    footnotes_styles <-
-      if (nrow(footnotes_style) > 0) {
-        paste(footnotes_style$html_style, collapse = " ")
-      } else {
-        NULL
+    if (footnotes_multiline) {
+      # Create one row per footnote
+      for (footnote in footnotes) {
+        footer_rows <- append(footer_rows, list(
+          htmltools::tags$tr(
+            class = "gt_footnotes",
+            htmltools::tags$td(
+              class = "gt_footnote",
+              style = footnotes_styles,
+              colspan = n_cols_total,
+              htmltools::HTML(footnote)
+            )
+          )
+        ))
       }
+    } else {
+      # Perform HTML escaping on the separator text and transform space
+      # characters to non-breaking spaces
+      footnotes_separator <-
+        gsub(" (?= )", "&nbsp;", footnotes_separator, perl = TRUE)
 
-  } else {
-    footnotes_styles <- NULL
+      # Create a single row with all footnotes
+      footer_rows <- append(footer_rows, list(
+        htmltools::tags$tr(
+          class = "gt_footnotes",
+          htmltools::tags$td(
+            class = "gt_footnote",
+            style = footnotes_styles,
+            colspan = n_cols_total,
+            htmltools::tags$div(
+              style = htmltools::css(`padding-bottom` = "2px"),
+              htmltools::HTML(paste(footnotes, collapse = footnotes_separator))
+            )
+          )
+        )
+      ))
+    }
   }
 
-  # Get the footnote multiline option
-  multiline <- dt_options_get_value(data = data, option = "footnotes_multiline")
+  # Add source note rows after footnotes
+  if (!is.null(source_notes)) {
 
-  # Get the footnote separator option
-  separator <- dt_options_get_value(data = data, option = "footnotes_sep")
+    # Get the style attrs for the source notes
+    source_notes_styles <- NULL
+    if ("source_notes" %in% styles_tbl$locname) {
+      source_notes_style <-
+        vctrs::vec_slice(
+          styles_tbl$html_style,
+          !is.na(styles_tbl$locname) & styles_tbl$locname == "source_notes"
+        )
 
-  # Obtain vectors of footnote ID values (prerendered glyphs) and
-  # the associated text
-  footnote_ids <- footnotes_tbl[["fs_id"]]
-  footnote_text <- footnotes_tbl[["footnotes"]]
+      source_notes_styles <-
+        if (length(source_notes_style) > 0) {
+          paste(source_notes_style, collapse = " ")
+        } else {
+          NULL
+        }
+    }
 
-  # Create a vector of HTML footnotes
-  footnotes <-
-    unlist(
-      mapply(
-        SIMPLIFY = FALSE,
-        USE.NAMES = FALSE,
-        footnote_ids,
-        footnote_text,
-        FUN = function(x, footnote_text) {
-          as.character(
-            htmltools::tagList(
+    # Get the source note multiline option
+    source_notes_multiline <-
+      dt_options_get_value(data = data, option = "source_notes_multiline")
+
+    # Get the source note separator option
+    source_notes_separator <-
+      dt_options_get_value(data = data, option = "source_notes_sep")
+
+    if (source_notes_multiline) {
+      # Create one row per source note
+      for (source_note in source_notes) {
+        footer_rows <- append(footer_rows, list(
+          htmltools::tags$tr(
+            class = "gt_sourcenotes",
+            htmltools::tags$td(
+              class = "gt_sourcenote",
+              style = source_notes_styles,
+              colspan = n_cols_total,
+              htmltools::HTML(source_note)
+            )
+          )
+        ))
+      }
+    } else {
+      # Perform HTML escaping on the separator text and transform space
+      # characters to non-breaking spaces
+      source_notes_separator <-
+        gsub(" (?= )", "&nbsp;", source_notes_separator, perl = TRUE)
+
+      # Create a single row with all source notes
+      footer_rows <- append(footer_rows, list(
+        htmltools::tags$tr(
+          class = "gt_sourcenotes",
+          htmltools::tags$td(
+            class = "gt_sourcenote",
+            style = source_notes_styles,
+            colspan = n_cols_total,
+            htmltools::tags$div(
+              style = htmltools::css(`padding-bottom` = "2px"),
               htmltools::HTML(
-                paste0(
-                  footnote_mark_to_html(
-                    data = data,
-                    mark = x,
-                    location = "ftr"
-                  ),
-                  " ",
-                  process_text(footnote_text, context = "html")
-                ),
-                .noWS = c("after", "before")
+                paste(source_notes, collapse = source_notes_separator)
               )
             )
           )
-        }
-      )
-    )
-
-  # Handle the multiline footnotes case (each footnote takes up one line)
-  if (multiline) {
-
-    # Create the footnotes component as a series of `<tr><td>` (one per
-    # footnote) inside of a `<tfoot>`
-    return(
-      htmltools::tags$tfoot(
-        class = "gt_footnotes",
-        lapply(
-          footnotes,
-          function(x) {
-            htmltools::tags$tr(
-              htmltools::tags$td(
-                class = "gt_footnote",
-                style = footnotes_styles,
-                colspan = n_cols_total,
-                htmltools::HTML(x)
-              )
-            )
-          }
         )
-      )
-    )
+      ))
+    }
   }
 
-  # Perform HTML escaping on the separator text and transform space
-  # characters to non-breaking spaces
-  separator <- gsub(" (?= )", "&nbsp;", separator, perl = TRUE)
-
-  # Create the footnotes component as a single `<tr><td>` inside
-  # of a `<tfoot>`
-  htmltools::tags$tfoot(
-    htmltools::tags$tr(
-      class = "gt_footnotes",
-      style = footnotes_styles,
-      htmltools::tags$td(
-        class = "gt_footnote",
-        colspan = n_cols_total,
-        htmltools::tags$div(
-          style = htmltools::css(`padding-bottom` = "2px"),
-          htmltools::HTML(paste(footnotes, collapse = separator))
-        )
-      )
-    )
-  )
+  # Return a single tfoot with all rows
+  if (length(footer_rows) > 0) {
+    htmltools::tags$tfoot(footer_rows)
+  } else {
+    ""
+  }
 }
 
 summary_rows_for_group_h <- function(
@@ -2059,8 +2297,8 @@ build_row_styles <- function(
 
   # The styles_resolved_row data frame should contain the columns `colnum` and
   # `html_style`. Each colnum should match the number of a data column in the
-  # output table; the first data column is number 1. No colnum should appear
-  # more than once in styles_resolved_row. It's OK for a column not to appear in
+  # output table; the first data column is number 1. No colnum should appear in
+  # styles_resolved_row, and it's OK for a column not to appear in
   # styles_resolved_row, and it's OK for styles_resolved_row to have 0 rows.
   #
   # If `include_stub` is TRUE, then a row with column==0 will be used as the
@@ -2096,6 +2334,86 @@ build_row_styles <- function(
   result
 }
 
+build_row_styles_with_stub_columns <- function(
+    styles_resolved_row,
+    stub_column_styles,
+    include_stub,
+    n_cols,
+    data
+) {
+
+  # First, build normal row styles
+  row_styles <- build_row_styles(
+    styles_resolved_row = styles_resolved_row,
+    include_stub = include_stub,
+    n_cols = n_cols
+  )
+
+  # If we have stub column styles and a stub exists, modify the stub styles
+  if (include_stub && nrow(stub_column_styles) > 0) {
+
+    # Get stub variables to map column names to positions
+    stub_vars <- dt_boxhead_get_var_stub(data = data)
+
+    if (!all(is.na(stub_vars))) {
+      # Create mapping from column names to stub positions
+      stub_positions <- seq_along(stub_vars)
+      names(stub_positions) <- stub_vars
+
+      # Apply per-column stub styles
+      for (j in seq_len(nrow(stub_column_styles))) {
+        col_name <- stub_column_styles$colname[j]
+        if (col_name %in% names(stub_positions)) {
+          stub_pos <- stub_positions[col_name]
+          # Apply style to the correct stub position
+          # Each stub column has its own position in the row_styles array
+          if (stub_pos <= length(row_styles)) {
+            # MERGE styles instead of overwriting
+            existing_style <- row_styles[stub_pos]
+            new_style <- stub_column_styles$html_style[j]
+
+            if (is.na(existing_style) || existing_style == "") {
+              row_styles[stub_pos] <- new_style
+            } else if (!is.na(new_style) && new_style != "") {
+              # Merge CSS styles by combining them
+              row_styles[stub_pos] <- paste(existing_style, new_style, sep = "; ")
+            }
+          }
+        }
+      }
+    }
+  }
+
+  # For multi-column stubs, modify border widths for internal columns
+  if (include_stub) {
+    stub_vars <- dt_boxhead_get_var_stub(data = data)
+
+    if (length(stub_vars) > 1 && !all(is.na(stub_vars))) {
+      # Multi-column stub: apply half-thickness borders to internal columns
+      for (i in seq_along(stub_vars)) {
+        if (i < length(stub_vars)) {
+          # Internal stub columns: use half-thickness border (1px instead of 2px)
+          border_override <- "border-right-width: 1px"
+
+          if (is.na(row_styles[i]) || row_styles[i] == "") {
+            row_styles[i] <- border_override
+          } else {
+            # Check if border-right-width is already set and replace it
+            if (grepl("border-right-width:", row_styles[i])) {
+              row_styles[i] <- gsub("border-right-width:[^;]*", "border-right-width: 1px", row_styles[i])
+            } else {
+              row_styles[i] <- paste(row_styles[i], border_override, sep = "; ")
+            }
+          }
+        }
+        # Last column keeps default border-right-width (2px from CSS)
+      }
+    }
+  }
+
+  row_styles
+}
+
 as_css_font_family_attr <- function(font_vec, value_only = FALSE) {
 
   fonts_spaces <- grepl(" ", font_vec)
@@ -2121,3 +2439,98 @@ valid_html_id <- function(x) {
   x[!valid_ids] <- paste0("a", x[!valid_ids])
   gsub("\\s+", "-", x)
 }
+
+# Function to calculate rowspan values for hierarchical stub columns
+calculate_hierarchical_stub_rowspans <- function(data) {
+
+  # Get stub layout and information
+  stub_layout <- get_stub_layout(data = data)
+  boxh <- dt_boxhead_get(data = data)
+
+  # Check if we have multiple stub columns
+  stub_vars <- dt_boxhead_get_var_stub(data = data)
+
+  if (length(stub_vars) == 1 && is.na(stub_vars)) {
+    # No stub columns
+    return(NULL)
+  }
+
+  if (length(stub_vars) <= 1) {
+    # Single stub column or no stub - no hierarchical merging needed
+    return(NULL)
+  }
+
+  # Get the body data for stub columns using the original data (before footnotes)
+  # This is crucial to avoid footnote markup interfering with hierarchical grouping
+  original_body <- dt_data_get(data = data)
+  n_rows <- nrow(original_body)
+
+  if (n_rows == 0) {
+    return(NULL)
+  }
+
+  # Create a matrix of stub values (excluding the rightmost column which is the row identifier)
+  hierarchy_vars <- stub_vars[-length(stub_vars)]  # Remove rightmost stub column
+  stub_matrix <- as.matrix(original_body[, hierarchy_vars, drop = FALSE])
+
+  # Initialize rowspan information
+  rowspan_info <- list()
+
+  # For each hierarchical stub column (left to right, excluding rightmost)
+  for (col_idx in seq_along(hierarchy_vars)) {
+    var_name <- hierarchy_vars[col_idx]
+    col_values <- stub_matrix[, col_idx]
+
+    # Calculate rowspans for this column based on consecutive identical values
+    # and values in columns to the left
+    rowspans <- rep(1L, n_rows)
+    display_mask <- rep(TRUE, n_rows)  # TRUE = display value, FALSE = merge/hide
+
+    current_span_start <- 1
+
+    for (row_idx in 2:n_rows) {
+      # Check if current row should continue the span from previous row
+      should_continue_span <- TRUE
+
+      # Must match current column value
+      if (col_values[row_idx] != col_values[row_idx - 1]) {
+        should_continue_span <- FALSE
+      }
+
+      # Must match all values in columns to the left
+      if (col_idx > 1) {
+        for (left_col_idx in 1:(col_idx - 1)) {
+          if (stub_matrix[row_idx, left_col_idx] != stub_matrix[row_idx - 1, left_col_idx]) {
+            should_continue_span <- FALSE
+            break
+          }
+        }
+      }
+
+      if (should_continue_span) {
+        # Continue the current span
+        display_mask[row_idx] <- FALSE
+      } else {
+        # End current span and start a new one
+        span_length <- row_idx - current_span_start
+        if (span_length > 1) {
+          rowspans[current_span_start] <- span_length
+        }
+        current_span_start <- row_idx
+      }
+    }
+
+    # Handle the last span
+    span_length <- n_rows - current_span_start + 1
+    if (span_length > 1) {
+      rowspans[current_span_start] <- span_length
+    }
+
+    rowspan_info[[var_name]] <- list(
+      rowspans = rowspans,
+      display_mask = display_mask
+    )
+  }
+
+  rowspan_info
+}
