@@ -88,11 +88,14 @@ latex_body_row <- function(content, type) {
 }
 
 #' @noRd
-latex_heading_row <- function(content) {
+latex_heading_row <- function(content, header_repeat = FALSE) {
+
 
   paste0(
     paste(paste(content, collapse = " & "), "\\\\ \n"),
-    "\\midrule\\addlinespace[2.5pt]\n",
+    "\\midrule",
+    if (header_repeat) {"\\endhead"},
+    "\\addlinespace[2.5pt]\n",
     collapse = ""
   )
 }
@@ -126,10 +129,11 @@ latex_group_row <- function(
 
 #' @noRd
 create_wrap_start_l <- function(data) {
-  if (check_quarto()) {
+  tbl_pos_val <- dt_options_get_value(data = data, option = "latex_tbl_pos")
+  if (check_quarto() || is.na(tbl_pos_val)) {
     tbl_pos <- ""
   } else {
-    tbl_pos <- paste0("[", dt_options_get_value(data = data, option = "latex_tbl_pos"), "]")
+    tbl_pos <- paste0("[", tbl_pos_val, "]")
   }
 
   ifelse(
@@ -384,14 +388,38 @@ create_heading_component_l <- function(data) {
     footnote_subtitle_marks <- ""
   }
 
-  title_row <- latex_group("\\large ", heading$title, footnote_title_marks)
+  title_font_size <- dt_options_get_value(data, "heading_title_font_size")
+  table_font_size <- dt_options_get_value(data, "table_font_size")
+
+  if(identical(title_font_size,"default")){
+    title_font_size <- table_font_size
+  }
+
+  title_row <- latex_group(
+    convert_font_size_l(title_font_size),
+    " ",
+    heading$title,
+    footnote_title_marks,
+    convert_font_size_l(table_font_size)
+    )
 
   if (subtitle_defined) {
 
+    subtitle_font_size <- dt_options_get_value(data, "heading_subtitle_font_size")
+
+    if(identical(subtitle_font_size,"default")){
+      subtitle_font_size <- table_font_size
+    }
+
     subtitle_row <-
       paste0(
         " \\\\ \n",
-        latex_group("\\small ", heading$subtitle, footnote_subtitle_marks)
+        latex_group(
+          convert_font_size_l(subtitle_font_size),
+          " ",
+          heading$subtitle,
+          footnote_subtitle_marks,
+          convert_font_size_l(table_font_size))
       )
 
   } else {
@@ -490,8 +518,10 @@ create_columns_component_l <- function(data, colwidth_df) {
     headings_labels <- prepend_vec(headings_labels, stub_label)
   }
 
+  header_repeat <- dt_options_get_value(data, "latex_header_repeat")
+
   table_col_headings <-
-    paste0(latex_heading_row(content = headings_labels), collapse = "")
+    paste0(latex_heading_row(content = headings_labels, header_repeat = header_repeat), collapse = "")
 
   if (spanner_row_count > 0) {
 
@@ -595,8 +625,10 @@ create_columns_component_l <- function(data, colwidth_df) {
     table_col_spanners <- ""
   }
 
+  include_toprule <- dt_options_get_value(data, "latex_toprule")
+
   paste0(
-    "\\toprule\n",
+    if (include_toprule) {"\\toprule\n"},
     paste0(table_col_spanners, collapse = ""),
     table_col_headings
   )
@@ -637,7 +669,7 @@ create_body_component_l <- function(data, colwidth_df) {
         n_rows_in_group <- n_rows_in_group + dim(list_of_summaries$summary_df_data_list[[i]])[1L]
       }
       row_splits_body[[groups_rows_df$row_start[i]]][1] <-
-        sprintf("\\multirow{%d}{%s}{%s}",
+        sprintf("\\multirow[t]{%d}{%s}{%s}",
                 n_rows_in_group,
                 if (colwidth_df$unspec[1L] == 1L) "*" else "=",
                 groups_rows_df$group_label[i])
@@ -1027,8 +1059,11 @@ summary_rows_for_group_l <- function(
 #' @noRd
 create_table_end_l <- function(data) {
 
+  include_bottomrule <- dt_options_get_value(data, "latex_bottomrule")
+
+
   paste0(
-    "\\bottomrule\n",
+    if(include_bottomrule){"\\bottomrule\n"},
     ifelse(dt_options_get_value(data = data, option = "latex_use_longtable"),
            "\\end{longtable}\n",
            "\\end{tabular*}\n"),
@@ -1253,11 +1288,16 @@ convert_font_size_l <- function(x) {
     large = "\\large ",
     `x-large` = "\\Large ",
     `xx-large` = "\\LARGE ",
-    `xxx-large` = "\\huge "
+    `xxx-large` = "\\huge ",
+    `default` = ""
   )
 
-  if (as.character(x) %in% names(size_map))
+
+  if (as.character(x) %in% names(size_map)){
     return(size_map[[x]])
+  }else if(grepl("(pt|%|px|in|cm|emu|em)",x)){
+    return(.apply_style_fontsize_l(list('cell_text' = list('size' = round(parse_font_size_l(x))))))
+  }
 
   NULL
 }
@@ -1492,6 +1532,7 @@ apply_cell_styles_l <- function(content, style_obj) {
     # Apply changes that can be made to the bracketed environment
     out_text <- paste0(
       "{",
+
       .apply_style_style_l(style_obj),
       .apply_style_weight_l(style_obj),
       # Can generate "\small for example
@@ -1581,9 +1622,9 @@ apply_cell_styles_l <- function(content, style_obj) {
     return(
       paste0(
         "\\fontsize{",
-        style_obj[["cell_text"]][["size"]] * 0.75,
+        round(style_obj[['cell_text']][['size']] * 0.75),
         "}{",
-        style_obj[["cell_text"]][["size"]] * 0.75 * 1.25,
+        round(style_obj[['cell_text']][['size']] * 0.75 * 1.25),
         "}\\selectfont "
       )
     )
@@ -1669,30 +1710,30 @@ create_fontsize_statement_l <- function(data) {
 
   fs_fmt <- "\\fontsize{%3.1fpt}{%3.1fpt}\\selectfont\n"
   if (grepl(pattern = "^[[:digit:]]+(\\%|in|cm|emu|em|pt|px)$", size)) {
-
-    if (endsWith(size, "%")) {
-
-      multiple <- as.numeric(gsub("%", "", size, fixed = TRUE)) / 100
-      fs_statement <- sprintf(fs_fmt, multiple * 12, multiple * 12 * 1.2)
-
-    } else if (endsWith(size, "pt")) {
-
-      pt_size <- as.numeric(sub("pt$", "", size))
-      fs_statement <- sprintf(fs_fmt, pt_size, pt_size * 1.2)
-
-    } else {
-
-      pt_size <- convert_to_px(size) * 0.75
-      fs_statement <- sprintf(fs_fmt, pt_size, pt_size * 1.2)
-
-    }
-
-  } else return("")
+    font_size <- parse_font_size_l(size)
+    ## parse_font_size_l returns font size in p
+    fs_statement <- sprintf(fs_fmt, round(font_size*.75), round(font_size* 1.2 * .75))
+  } else {
+    return("")
+  }
 
   fs_statement
 
 }
 
+parse_font_size_l <- function(x){
+  if (endsWith(x, "%")) {
+
+    size <- (as.numeric(gsub("%", "", x, fixed = TRUE)) / 100) * 16 * (4/3) ## 12pt is default font size, 4/3 to convert to px
+
+  } else {
+
+    size <- convert_to_px(x)
+  }
+
+  size
+}
+
 create_colwidth_df_l <- function(data) {
 
   boxhead <- dt_boxhead_get(data)
