@@ -216,3 +216,23 @@ test_that("The stub gets its alignment set properly with `cols_align()`", {
     cols_align(align = "center", columns = stub())
   )
 })
+
+
+test_that("check cols_align is applied gt_group", {
+
+  # Create a `gt_group` object of two `gt_tbl`s
+  # create gt group example
+  gt_tbl <- mtcars_short %>% gt()
+  gt_group <- gt_group(gt_tbl, gt_tbl)
+
+  # apply alignment to table and group
+  aligned_gt_tbl <- gt_tbl %>%
+    cols_align(align = "left", columns = c(mpg, cyl, drat))
+
+  aligned_gt_group <- gt_group %>%
+    cols_align(align = "left", columns = c(mpg, cyl, drat))
+
+  # Expect identical if function applied before or after group is constructed
+  expect_identical(aligned_gt_group, gt_group(aligned_gt_tbl, aligned_gt_tbl))
+
+})
